@@ -27,7 +27,7 @@ from senlinclient.common import utils as senlin_utils
 
 
 class ListNode(command.Lister):
-    """Show list of nodes."""
+    """List nodes."""
 
     log = logging.getLogger(__name__ + ".ListNode")
 
@@ -329,9 +329,9 @@ class DeleteNode(command.Command):
         result = {}
         for nid in parsed_args.node:
             try:
-                node = senlin_client.delete_node(
+                node_delete_action = senlin_client.delete_node(
                     nid, False, parsed_args.force_delete)
-                result[nid] = ('OK', node.location.split('/')[-1])
+                result[nid] = ('OK', node_delete_action['id'])
             except Exception as ex:
                 result[nid] = ('ERROR', six.text_type(ex))
 
@@ -361,9 +361,12 @@ class CheckNode(command.Command):
                 resp = senlin_client.check_node(nid)
             except sdk_exc.ResourceNotFound:
                 raise exc.CommandError(_('Node not found: %s') % nid)
-            print('Node check request on node %(nid)s is accepted by '
-                  'action %(action)s.'
-                  % {'nid': nid, 'action': resp['action']})
+            if 'action' in resp:
+                print('Node check request on node %(nid)s is accepted by '
+                      'action %(action)s.'
+                      % {'nid': nid, 'action': resp['action']})
+            else:
+                print('Request error: %s' % resp)
 
 
 class RecoverNode(command.Command):
@@ -400,9 +403,12 @@ class RecoverNode(command.Command):
                 resp = senlin_client.recover_node(nid, **params)
             except sdk_exc.ResourceNotFound:
                 raise exc.CommandError(_('Node not found: %s') % nid)
-            print('Node recover request on node %(nid)s is accepted by '
-                  'action %(action)s.'
-                  % {'nid': nid, 'action': resp['action']})
+            if 'action' in resp:
+                print('Node recover request on node %(nid)s is accepted by '
+                      'action %(action)s.'
+                      % {'nid': nid, 'action': resp['action']})
+            else:
+                print('Request error: %s' % resp)
 
 
 class AdoptNode(command.ShowOne):
@@ -540,6 +546,9 @@ class NodeOp(command.Lister):
         try:
             resp = senlin_client.perform_operation_on_node(
                 nid, parsed_args.operation, **params)
-            print('Request accepted by action: %s' % resp['action'])
         except sdk_exc.ResourceNotFound:
             raise exc.CommandError(_('Node not found: %s') % nid)
+        if 'action' in resp:
+            print('Request accepted by action: %s' % resp['action'])
+        else:
+            print('Request error: %s' % resp)
